/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef GNOMEVFS_MOUNT_H
#define GNOMEVFS_MOUNT_H

#ifdef HAVE_CONFIG_H 
#include "config.h"
#endif

#include <stdio.h>
#include <string.h>
#include <time.h>
 
#include <errno.h>
#include <fcntl.h>
#include <sys/stat.h>
#include <unistd.h>
#include <sys/types.h>
#include <getopt.h>

#include <glib.h>
#include <libgnomevfs/gnome-vfs.h>

#ifdef HAVE_GNOME_KEYRING
#include <gnome-keyring.h>
#endif

#include <fuse.h>

G_BEGIN_DECLS

static void gnome_vfs_mount_init();

static void gnome_vfs_mount_shutdown();

static void gnome_vfs_mount_critical(GnomeVFSResult code, const gchar *path);

static void gnome_vfs_mount_message(gchar const *format, ...);

static GnomeVFSResult gnome_vfs_mount_get_file_info_uri(
	const gchar *relative_path,
	GnomeVFSFileInfo *info,
	GnomeVFSFileInfoOptions options);

static int gnome_vfs_mount_getattr(const char *path, struct stat *stbuf);

static int gnome_vfs_mount_readlink(const char *path, char *buf, size_t size);

static int gnome_vfs_mount_getdir(const char *path, fuse_dirh_t h, fuse_dirfil_t filler);

static int gnome_vfs_mount_open(const char *path, int flags);

static int gnome_vfs_mount_read(const char *path, char *buf, size_t size, off_t offset);

static int gnome_vfs_mount_write(const char *path, const char *buf,size_t size, off_t offset);

static int gnome_vfs_mount_truncate(const char *path, off_t size);

static int gnome_vfs_mount_mkdir(const char *path, mode_t mode);

static int gnome_vfs_mount_rmdir(const char *path);

static int gnome_vfs_mount_unlink(const char *path);

static int gnome_vfs_mount_utime(const char *path, struct utimbuf *buf);

static int gnome_vfs_mount_mknod(const char *path, mode_t mode, dev_t rdev);

static int gnome_vfs_mount_symlink(const char *from, const char *to);

static int gnome_vfs_mount_rename(const char *from, const char *to);

static int gnome_vfs_mount_chmod(const char *path, mode_t mode);

static int gnome_vfs_mount_chown(const char *path, uid_t uid, gid_t gid);

static int gnome_vfs_mount_release(const char *path, int flags);

static void usage(char *program_name);

static void gnome_vfs_mount_auth_callback(
		gconstpointer in, size_t in_size, 
		gpointer out, size_t out_size, 
		gpointer user_data);

G_END_DECLS

#endif
